
==========
javasphinx
==========

javasphinx is an extension to the Sphinx documentation system which adds support
for documenting Java projects. It includes a Java domain for writing
documentation manually and a javasphinx-apidoc utility which will automatically
generate API documentation from existing Javadoc markup.

javasphinx is available in the Python Package Index (PyPi) under the name
*javasphinx* and can be installed using tools such as ``pip`` or
``easy_install``.

Documentation for javasphinx is available at http://bronto.github.com/javasphinx/
